@@ -1,7 +1,8 @@
 ## ----setup, include = FALSE---------------------------------------------------
 knitr::opts_chunk$set(
 	collapse = TRUE,
-	comment = "#>"
+	comment = "#>",
+	eval = nzchar(Sys.getenv("COMPILE_VIG"))
 )
 library(cansim)
 
